/******************************************************************************
 commands.c - et serial commands source file 
 Version: 0.9.1
 Created on: 29/06/2021
 Created by: Rohit Rajapure

 Copyright (c) 2017 Shalaka Connected Devices LLP.  All rights reserved.
 Software License Agreement

   Redistribution and use in source and binary forms, with or without
   modification, are not permitted.

   Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

   Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the
   distribution.

   Neither the name of Shalaka Connected Devices LLP nor the names of
   its contributors may be used to endorse or promote products derived
   from this software without specific prior written permission.

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ******************************************************************************/

#include <stdbool.h>
#include <stdint.h>
#include <stdio.h>
#include "string.h"

#include "app_uart.h"
#include "app_error.h"
#include "nrf_delay.h"
#include "nrf.h"

#include "uart_config.h"
#include "gpio_config.h"
#include "timer_config.h"
#include "commands.h" 
#include "uart_statemachine.h" 
#include "app_rtc.h"
#include "zb_custom1_thermostat.h"
#include "custom_app_event.h"
/*******************************************************************************************
*MACROS
*
*******************************************************************************************/

/******************************************************************************************
*EXTERNAL VARIABLES
*
*******************************************************************************************/
extern bool boolReady;
extern bool boolIsMCURequest; //this flag is general to send getflag command whenever requried. So, set this flag accordingly.
extern uint8_t ui8RTCArray [6];
extern uint16_t ui16CurrentTemp,ui16OccupiedHeatSetpoint,ui16UnOccupiedHeatSetpoint;
extern uint32_t ui32HostflagsData;
extern App_tsEventUart sAppUartEvent;
extern E_StateMachineThermostat e_StateMachineThermostat;
/******************************************************************************************
*LOCAL VARIABLES
*
*******************************************************************************************/
uint8_t ui8Count = 0;
uint8_t ui8SetCount = 0;
uint8_t ui8GetCommandBuffer[BUFFER_SIZE], ui8SetCommandBuffer[BUFFER_SIZE], ui8SendDeviceConfig[BUFFER_SIZE],ui8GetFlagBuffer[BUFFER_SIZE], ui8ResponceValueSend[BUFFER_SIZE], ui8ResponceValueSend2[BUFFER_SIZE], ui8StartFirmwareUpdate[BUFFER_SIZE], ui8TransferFirmware[BUFFER_SIZE], ui8TempGetFlagBuffer[BUFFER_SIZE];



/******************************************************************************************
*FUNCTIONS
*
*******************************************************************************************/
/*******************************************
 * Functions to convert packets into Eurotronic Radiator Commands
 * Each command consists of following data bytes
 * sync, packet length, command ID, Data Bytes, Checksum
 * param : command ID
 * return: ACK 
 ******************************************/
uint8_t GetMessageIdResponse(uint8_t ui8MessageId)
{
    ui8GetCommandBuffer[0] = SYNC;  //first byte is sys byte 
    ui8GetCommandBuffer[1] = MIN_COMMAND_LENGTH; //all get commands max length is 4
    ui8GetCommandBuffer[2] = ui8MessageId;
    ui8GetCommandBuffer[3] = ui8GenerateCheckSum(ui8GetCommandBuffer,MIN_COMMAND_LENGTH);
    
    return(RESP_ACK);
}

uint8_t SetFlags()
{
    ui8SetCount=4;
    ui8SetCommandBuffer[0]=SYNC;
    ui8SetCommandBuffer[2]= SET_FLAGS;
    ui8SetCount+=5;
    ui8SetCommandBuffer[1]=ui8SetCount;
    ui8SetCommandBuffer[3]=0x00;
    ui8SetCommandBuffer[7]=0x40;
    ui8SetCommandBuffer[8]=ui8GenerateCheckSum(ui8SetCommandBuffer, ui8SetCount);

    return(RESP_ACK);
};

uint8_t SendSetTemperature()
{
    ui8SetCount=4;
    ui8SetCommandBuffer[0]=SYNC;
    ui8SetCommandBuffer[2]= SET_TEMPERATURES;
    ui8SetCount+=12;
    ui8SetCommandBuffer[1]=ui8SetCount;
    ui8SetCommandBuffer[3]= 0xFF;
    ui8SetCommandBuffer[4]= 0xFF;
    ui8SetCommandBuffer[5]= 0xFF;
    ui8SetCommandBuffer[6]= 0xFF;
    ui8SetCommandBuffer[7]= ui16CurrentTemp >> 8;
    ui8SetCommandBuffer[8]= ui16CurrentTemp & 0x00FF;
    ui8SetCommandBuffer[9]= ui16UnOccupiedHeatSetpoint >> 8;
    ui8SetCommandBuffer[10]= ui16UnOccupiedHeatSetpoint & 0x00FF;
    ui8SetCommandBuffer[11]= ui16OccupiedHeatSetpoint >> 8;
    ui8SetCommandBuffer[12]= ui16OccupiedHeatSetpoint & 0x00FF;
    ui8SetCommandBuffer[13]= 0xFF;
    ui8SetCommandBuffer[14]= 0xFF;
    ui8SetCommandBuffer[15]=ui8GenerateCheckSum(ui8SetCommandBuffer, ui8SetCount);

    return(RESP_ACK);
}

/****************************************************************************
 *
 * NAME: UARTStateSendFlags
 *
 * DESCRIPTION:
 * send flag (set flag) when Host attribute changed 
 *
 * RETURNS:
 * void
 *
 ****************************************************************************/
void UARTStateSendFlags(void)
{
    ui8SetCount=4;
    ui8SetCommandBuffer[0]=SYNC;
    ui8SetCommandBuffer[2]= SET_FLAGS;
    ui8SetCount+=5;
    ui8SetCommandBuffer[1]=ui8SetCount;

    if((ui32HostflagsData & 0x000001)== 0x01)
    {
       ui8SetCommandBuffer[3] = ui8SetCommandBuffer[3] | 0x01;
    }

    //Boost mode data 2
    if((ui32HostflagsData & 0x000004)== 0x04)
    {
      ui8SetCommandBuffer[4] = ui8SetCommandBuffer[4]| FLAGS_BYTE_2_BOOST_MODE; //Boost mode ON
    }
    if((ui32HostflagsData ^ 0x000004)& 0x04)
    {
      ui8SetCommandBuffer[4] &= ui8SetCommandBuffer[4]^ FLAGS_BYTE_2_BOOST_MODE;  //Boost mode OFF
    }
    //stop window open detection 0x10
     if((ui32HostflagsData & 0x000010) == 0x10)
     {
       ui32HostflagsData &= ui32HostflagsData^ 0x10;
       ui8SetCommandBuffer[3] &= ui8SetCommandBuffer[3] ^ 0x10;
     }
     //Start window open detection 0x20
     if((ui32HostflagsData & 0x000020) == 0x20)
     {
       ui8SetCommandBuffer[3] = ui8SetCommandBuffer[3] | 0x10;
     }
    //key/child protection 
    if((ui32HostflagsData & 0x000080) == 0x80)
    {
       ui8SetCommandBuffer[3] = ui8SetCommandBuffer[3] | 0x04;   //key/child protection Activate
    }
    if((ui32HostflagsData^ 0x000080) & 0x80)
    {
       if((ui8SetCommandBuffer[3] & 0x04) == 0x04)
       {
          ui8SetCommandBuffer[3] &= ui8SetCommandBuffer[3] ^ 0x04; //key/child protection Deactivate
       }
    }
    ui8SetCommandBuffer[7]=0x40;
    ui8SetCommandBuffer[8]=ui8GenerateCheckSum(ui8SetCommandBuffer, ui8SetCount);
}
/****************************************************************************
 *
 * NAME: UARTStateSendFlagsAuto
 *
 * DESCRIPTION:
 * Flags nach Device Configuration synchronisieren
 *
 * RETURNS:
 * void
 *
 ****************************************************************************/
void UARTStateSendFlagsAuto(void)
{
    ui8SetCount=4;
    ui8SetCommandBuffer[0]=SYNC;
    ui8SetCommandBuffer[2] = SET_FLAGS;
    ui8SetCount+=5;
    ui8SetCommandBuffer[1]=ui8SetCount;
    ui8SetCommandBuffer[3] &= ui8SetCommandBuffer[3] ^ FLAGS_BYTE_1_MANU_MODE;
   
    //m_dev_ctx.thermostat_attr.host_flags &=  m_dev_ctx.thermostat_attr.host_flags ^ FLAGS_BYTE_1_MANU_MODE; 
    ui8SetCommandBuffer[8]=ui8GenerateCheckSum(ui8SetCommandBuffer, ui8SetCount); 
}

/****************************************************************************
 *
 * NAME: UARTStateSendFlagsManu
 *
 * DESCRIPTION:
 * Flags nach Device Configuration synchronisieren
 *
 * RETURNS:
 * void
 *
 ****************************************************************************/
void UARTStateSendFlagsManu(void) 
{
    ui8SetCount=4;
    ui8SetCommandBuffer[0]=SYNC;
    ui8SetCommandBuffer[2] = SET_FLAGS;
    ui8SetCount+=5;
    ui8SetCommandBuffer[1]=ui8SetCount;
    //Manu Mode = 0x01 aktivieren
    ui8SetCommandBuffer[3] = ui8SetCommandBuffer[3] | FLAGS_BYTE_1_MANU_MODE;
    
    //m_dev_ctx.thermostat_attr.host_flags = m_dev_ctx.thermostat_attr.host_flags | FLAGS_BYTE_1_MANU_MODE;
    ui8SetCommandBuffer[8]=ui8GenerateCheckSum(ui8SetCommandBuffer, ui8SetCount);
}

/****************************************************************************
 *
 * NAME: UARTStateSendValvePosition
 *
 * DESCRIPTION:
 * Send valve position
 *
 * RETURNS:
 * void
 *
 ****************************************************************************/
void UARTStateSendValvePosition(void) 
{
    ui8SetCount=4;
    ui8SetCommandBuffer[0]=SYNC;
    ui8SetCommandBuffer[2] = SET_POSITION;
    ui8SetCount+=1;
    ui8SetCommandBuffer[1]=ui8SetCount;
    ui8SetCommandBuffer[3] = m_dev_ctx.thermostat_attr.set_valve_position;
    ui8SetCommandBuffer[4]=ui8GenerateCheckSum(ui8SetCommandBuffer, ui8SetCount);
}
/****************************************************************************
 *
 * NAME: UARTStateSendDeviceConfig
 *
 * DESCRIPTION:
 * Device config senden
 *
 * RETURNS:
 * void
 *
 ****************************************************************************/
void UARTStateSendDeviceConfig(void) 
{
    ui8SetCount=4;
    ui8SendDeviceConfig[0]=SYNC;
    ui8SendDeviceConfig[2] = SET_DEVICE_CONFIG;
    ui8SetCount+=4;
    ui8SendDeviceConfig[1] =ui8SetCount;
    ui8SendDeviceConfig[3] = 0x05; //Window open detection threshold
    ui8SendDeviceConfig[4] = 0x0F; //Window open detection timer
    ui8SendDeviceConfig[5] |= DEVICE_CONFIG_BYTE_3_INTERNAL_WINDOW_OPEN;

    ui8SendDeviceConfig[6] = 0x05;// Delta measured temperature notification

    ui8SendDeviceConfig[7]=ui8GenerateCheckSum(ui8SendDeviceConfig, ui8SetCount);
}

/****************************************************************************
 *
 * NAME: UARTStateSendDeviceConfig2
 *
 * DESCRIPTION:
 * Device config send
 *
 * RETURNS:
 * void
 *
 ****************************************************************************/
void UARTStateSendDeviceConfig2(void) 
{
    ui8SetCount=4;
    ui8SetCommandBuffer[0]=SYNC;
    ui8SetCommandBuffer[2] = SET_DEVICE_CONFIG_2;
    ui8SetCount+=8;
    ui8SetCommandBuffer[1] =ui8SetCount;
    ui8SetCommandBuffer[3] = 0xFF; //Time for switchoff display
    ui8SetCommandBuffer[4] = 8; //Time in seconds for automatic switchoff backlight
    ui8SetCommandBuffer[5] = 15; // Time for Boost function in minutes
    ui8SetCommandBuffer[6] = 1; // Delta valve position changed
    ui8SetCommandBuffer[7] = 0xFF; // Display Contrast Level
    ui8SetCommandBuffer[8] = 0x00; // reserved
    ui8SetCommandBuffer[9] = 0x00;// reserved
    ui8SetCommandBuffer[10] = 0x00;// reserved
    ui8SetCommandBuffer[11]=ui8GenerateCheckSum(ui8SetCommandBuffer, ui8SetCount);
}
/****************************************************************************
 *
 * NAME: UARTStateSendFlagsLeave
 *
 * DESCRIPTION:
 * RF Symbol reset
 *
 * RETURNS:
 * void
 *
 ****************************************************************************/
void UARTStateSendFlagsLeave(void)
{
    ui8SetCount=4;
    ui8SetCommandBuffer[0]=SYNC;
    ui8SetCommandBuffer[2] = SET_FLAGS;
    ui8SetCount+=5;
    ui8SetCommandBuffer[1]=ui8SetCount;
//    if ((m_dev_ctx.thermostat_attr.host_flags & 0x0000FF)== 0x80) 
//    {
//        ui8SetCommandBuffer[3] = ui8SetCommandBuffer[3] | 0x04;
//    }
//    else 
//    {
//        ui8SetCommandBuffer[3] &= ui8SetCommandBuffer[3] ^ 0x04;
//    }
    ui8SetCommandBuffer[7] &= ui8SetCommandBuffer[7] ^ 0x40; // Device paired bit

    ui8SetCommandBuffer[8]=ui8GenerateCheckSum(ui8SetCommandBuffer, ui8SetCount);
}
/****************************************************************************
 *
 * NAME: UARTStateSendFlagsRFCommunicationOK
 *
 * DESCRIPTION:
 * RF Symbol reset
 *
 * RETURNS:
 * void
 *
 *****************************************************************************/
void UARTStateSendFlagsRFCommunicationOK(void) 
{
    ui8SetCount=4;
    ui8SetCommandBuffer[0]=SYNC;
    ui8SetCommandBuffer[2] = SET_FLAGS;
    ui8SetCount+=5;
    ui8SetCommandBuffer[1]=ui8SetCount; 
    ui8SetCommandBuffer[7] &= ui8SetCommandBuffer[7] ^ 0x20;
    ui8SetCommandBuffer[8]=ui8GenerateCheckSum(ui8SetCommandBuffer, ui8SetCount);
}
/****************************************************************************
 *
 * NAME: UARTStateSendFlagsRFCommunicationLost
 *
 * DESCRIPTION:
 * RF Symbol reset
 *
 * RETURNS:
 * void
 *
 *****************************************************************************/
void UARTStateSendFlagsRFCommunicationLost(void) 
{
    ui8SetCount=4;
    ui8SetCommandBuffer[0]=SYNC;
    ui8SetCommandBuffer[2] = SET_FLAGS;
    ui8SetCount+=5;
    ui8SetCommandBuffer[1]=ui8SetCount; 
    ui8SetCommandBuffer[7]|= 0x20;
    ui8SetCommandBuffer[8]=ui8GenerateCheckSum(ui8SetCommandBuffer, ui8SetCount);	
}
/****************************************************************************
 *
 * NAME: UARTStateSendFlagsJoined
 *
 * DESCRIPTION:
 * Flags senden
 *
 * RETURNS:
 * void
 *
 ****************************************************************************/
void UARTStateSendFlagsJoined(void) 
{
    ui8SetCount=4;
    ui8SetCommandBuffer[0]=SYNC;
    ui8SetCommandBuffer[2] = SET_FLAGS;
    ui8SetCount+=5;
    ui8SetCommandBuffer[1]=ui8SetCount;
//    if ((m_dev_ctx.thermostat_attr.host_flags & 0x0000FF)== 0x80) 
//    {
//        ui8SetCommandBuffer[3] = ui8SetCommandBuffer[3] | 0x04;
//    }
//    else 
//    {
//        ui8SetCommandBuffer[3] &= ui8SetCommandBuffer[3] ^ 0x04;
//    }
    ui8SetCommandBuffer[7] &= ui8SetCommandBuffer[7] ^ 0x40; // Device paired bit

    ui8SetCommandBuffer[8]=ui8GenerateCheckSum(ui8SetCommandBuffer, ui8SetCount);
}
/****************************************************************************
 *
 * NAME: UARTStateMasterResetRequest
 *
 * DESCRIPTION:
 * Flags send with Master Reset Request
 *
 * RETURNS:
 * void
 *
 ****************************************************************************/
void UARTStateMasterResetRequest(void)
{
  /*If the device is in production mode,
   * a MASTER RESET should not be performed,
   * because this reboots the device and the production mode is unnecessarily delayed*/
    if (ui8SetCommandBuffer[4] & FLAGS_BYTE_2_PRODUCTION_MODE)
    {
       UARTStateSendSetProductionModePass();
    }
    else
    {
       /*The MASTER RESET only wants to be executed during normal operation*/
        ui8SetCount=4;
        ui8SetCommandBuffer[0]=SYNC;
        ui8SetCommandBuffer[2] = SET_FLAGS;
        ui8SetCount+=5;
        ui8SetCommandBuffer[1]=ui8SetCount;

        ui8SetCommandBuffer[4] = ui8SetCommandBuffer[4] | FLAGS_BYTE_2_MASTER_RESET_REQUEST;
        ui8SetCommandBuffer[8]=ui8GenerateCheckSum(ui8SetCommandBuffer, ui8SetCount);
    }
}
/****************************************************************************
 *
 * NAME: UARTStateMasterResetSuccess
 *
 * DESCRIPTION:
 * Flags send with Master Reset Success
 *
 * RETURNS:
 * void
 *
 ****************************************************************************/
void UARTStateMasterResetSuccess(void)
{
    ui8SetCount=4;
    ui8SetCommandBuffer[0]=SYNC;
    ui8SetCommandBuffer[2] = SET_FLAGS;
    ui8SetCount+=5;
    ui8SetCommandBuffer[1]=ui8SetCount;
    ui8SetCommandBuffer[4] &= ui8SetCommandBuffer[4] ^ FLAGS_BYTE_2_MASTER_RESET_REQUEST; // Master Reset Request reset
    ui8SetCommandBuffer[4] = ui8SetCommandBuffer[4] | FLAGS_BYTE_2_MASTER_RESET_SUCCESS;
    ui8SetCommandBuffer[8] = ui8GenerateCheckSum(ui8SetCommandBuffer, ui8SetCount);
}

/****************************************************************************
 *
 * NAME: UARTStateSendSetProductionModePass
 *
 * DESCRIPTION:
 * Send Productions mode passed
 *
 * RETURNS:
 * void
 *
 ****************************************************************************/
void UARTStateSendSetProductionModePass(void)
{
    ui8SetCount=4;
    ui8SetCommandBuffer[0]=SYNC;
    ui8SetCommandBuffer[2] = SET_PRODUCTION_MODE;
    ui8SetCount+=2;
    ui8SetCommandBuffer[1]=ui8SetCount;
    ui8SetCommandBuffer[3] = 0x00;//0x00 Productionsmodus wird verlassen
    ui8SetCommandBuffer[4] = 0x00;
    ui8SetCommandBuffer[5]=ui8GenerateCheckSum(ui8SetCommandBuffer, ui8SetCount);

}
/****************************************************************************
 *
 * NAME: UARTStateSendStartProductionMode
 *
 * DESCRIPTION:
 * Activate production mode
 *
 * RETURNS:
 * void
 *
 ****************************************************************************/
void UARTStateSendStartProductionMode(void)
{
    ui8SetCount=4;
    ui8SetCommandBuffer[0]=SYNC;
    ui8SetCommandBuffer[2] = SET_PRODUCTION_MODE;
    ui8SetCount+=2;
    ui8SetCommandBuffer[1]=ui8SetCount;
    ui8SetCommandBuffer[3] = 0x01;//0x00 Productionsmodus wird verlassen
    ui8SetCommandBuffer[4] = 0x01;
    ui8SetCommandBuffer[5]=ui8GenerateCheckSum(ui8SetCommandBuffer, ui8SetCount);
}
/****************************************************************************
 *
 * NAME: UARTStateSendRTC
 *
 * DESCRIPTION:
 * send rtc
 *
 * RETURNS:
 * void
 *
 ****************************************************************************/
void UARTStateSendRTC(void) 
{
    ui8SetCount=4;
    ui8SetCommandBuffer[0]=SYNC;
    ui8SetCommandBuffer[2] = SET_RTC;
    ui8SetCount+=6;
    ui8SetCommandBuffer[1]=ui8SetCount;
    ui8SetCommandBuffer[3] = ui8RTCArray[0]; //Minute
    ui8SetCommandBuffer[4] = ui8RTCArray[1]; //Hour
    ui8SetCommandBuffer[5] = ui8RTCArray[2]; // Day
    ui8SetCommandBuffer[6] = ui8RTCArray[3]; // Weekday
    ui8SetCommandBuffer[7] = ui8RTCArray[4]; // Month
    ui8SetCommandBuffer[8] = ui8RTCArray[5]; // Year
    ui8SetCommandBuffer[9] = ui8GenerateCheckSum(ui8SetCommandBuffer, ui8SetCount);
}

/****************************************************************************
 *
 * NAME: UARTStateStartFirmwareUpdate
 *
 * DESCRIPTION:
 * Host Firmware Update start
 *
 * RETURNS:
 * void
 *
****************************************************************************/
void UARTStateStartFirmwareUpdate(void)
{
    ui8SetCount=4;
    ui8StartFirmwareUpdate[0]=SYNC;
    ui8StartFirmwareUpdate[2] = START_FIRMWARE_UPDATE;
    ui8SetCount+=6;
    ui8StartFirmwareUpdate[1]=ui8SetCount;
    ui8StartFirmwareUpdate[3]= 0x33;
    ui8StartFirmwareUpdate[4]= 0x31;
    ui8StartFirmwareUpdate[5]= 0x34;
    ui8StartFirmwareUpdate[6]= 0x31;
    ui8StartFirmwareUpdate[7]= 0x35;
    ui8StartFirmwareUpdate[8]= 0x39;
    ui8StartFirmwareUpdate[9]= ui8GenerateCheckSum(ui8StartFirmwareUpdate, ui8SetCount);

}

/****************************************************************************
 *
 * NAME: UARTStateTransferFirmwareUpdate
 *
 * DESCRIPTION:
 * Host transfer Firmware 
 *
 * RETURNS:
 * void
 *
****************************************************************************/
void UARTStateTransferFirmwareUpdate(void)
{
    ui8SetCount=4;
    ui8TransferFirmware[0]=SYNC;
    ui8TransferFirmware[2] = TRANSFER_FIRMWARE;
    ui8SetCount+=64;
    ui8TransferFirmware[1]= ui8SetCount;
    ui8TransferFirmware[67] = ui8GenerateCheckSum(ui8TransferFirmware, ui8SetCount);
}

/********************************************************************************************************************************/
// This function generate the checksum of command bytes returns checksum byte
/********************************************************************************************************************************/

uint8_t ui8GenerateCheckSum(uint8_t buffer[],uint8_t ui8Count)
{
    uint8_t ui8CheckSum=0,i;
    for(i=0;i<(ui8Count-1);i++)
        ui8CheckSum=ui8CheckSum+buffer[i];
    ui8CheckSum=0xFF-ui8CheckSum;
    ui8CheckSum=ui8CheckSum+1;
    return(ui8CheckSum);
}

//get bootloader commad creation 
void CommandBootloader (void)
{
   GetMessageIdResponse(GET_BOOTLOADER_STATE); 
   boolReady = true; //set flag to execute communication state
   boolIsMCURequest = true;
}


//void return function send different battery percentage level depending on various values
void vCalculateBattery(uint8_t u8BatteryInPercent) 
{

	if (u8BatteryInPercent >= 0xFF) {
		ReadRemainigBatteryPercentage(200);
	} else if (u8BatteryInPercent < 0xFF && u8BatteryInPercent >= 0xF2) {
		ReadRemainigBatteryPercentage(190);
	} else if (u8BatteryInPercent < 0xF2 && u8BatteryInPercent >= 0xE5) {
		ReadRemainigBatteryPercentage(180);
	} else if (u8BatteryInPercent < 0xE5 && u8BatteryInPercent >= 0xD8) {
		ReadRemainigBatteryPercentage(170);
	} else if (u8BatteryInPercent < 0xD8 && u8BatteryInPercent >= 0xCB) {
		ReadRemainigBatteryPercentage(160);
	} else if (u8BatteryInPercent < 0xCB && u8BatteryInPercent >= 0xBE) {
		ReadRemainigBatteryPercentage(150);
	} else if (u8BatteryInPercent < 0xBE && u8BatteryInPercent >= 0xB1) {
		ReadRemainigBatteryPercentage(140);
	} else if (u8BatteryInPercent < 0xB1 && u8BatteryInPercent >= 0xA4) {
		ReadRemainigBatteryPercentage(130);
	} else if (u8BatteryInPercent < 0xA4 && u8BatteryInPercent >= 0x97) {
		ReadRemainigBatteryPercentage(120);
	} else if (u8BatteryInPercent < 0x97 && u8BatteryInPercent >= 0x8A) {
		ReadRemainigBatteryPercentage(110);
	} else if (u8BatteryInPercent < 0x8A && u8BatteryInPercent >= 0x80) {
		ReadRemainigBatteryPercentage(100);
	} else if (u8BatteryInPercent < 0x80 && u8BatteryInPercent >= 0x73) {
		ReadRemainigBatteryPercentage(90);
	} else if (u8BatteryInPercent < 0x73 && u8BatteryInPercent >= 0x66) {
		ReadRemainigBatteryPercentage(80);
	} else if (u8BatteryInPercent < 0x66 && u8BatteryInPercent >= 0x59) {
		ReadRemainigBatteryPercentage(70);
	} else if (u8BatteryInPercent < 0x59 && u8BatteryInPercent >= 0x4C) {
		ReadRemainigBatteryPercentage(60);
	} else if (u8BatteryInPercent < 0x4C && u8BatteryInPercent >= 0x3F) {
		ReadRemainigBatteryPercentage(50);
	} else if (u8BatteryInPercent < 0x3F && u8BatteryInPercent >= 0x32) {
		ReadRemainigBatteryPercentage(40);
	} else if (u8BatteryInPercent < 0x32 && u8BatteryInPercent >= 0x25) {
		ReadRemainigBatteryPercentage(30);
	} else if (u8BatteryInPercent < 0x25 && u8BatteryInPercent >= 0x18) {
		ReadRemainigBatteryPercentage(20);
	} else if (u8BatteryInPercent < 0x18 && u8BatteryInPercent >= 0x0B) {
		ReadRemainigBatteryPercentage(10);
	} else if (u8BatteryInPercent < 0x0B && u8BatteryInPercent >= 0x00) {
		ReadRemainigBatteryPercentage(0);
	}
}